@@ -84,9 +84,9 @@ exports.report = function (req, res) {
     var parameters = {
         department: "it"
     };
-    var type = req.param("type");
+    //var type = req.param("type");
     //req.logger.info(type);
-    res.ireport("report1.jasper", type, datas, parameters);
+    res.ireport("report1.jasper", "pdf", datas, parameters);
 }
 
 exports.userinfo = function (req, res) {
