@@ -33,7 +33,9 @@ module.exports = function (nylon) {
 
     app.nylon = nylon;
     // app.nylon.r=db;
-    app.authenticate=authenticate;
+    app.nylon.authenticate=authenticate;
+   // console.log(app.authenticate);
+
     
 
     console.log("work_dir::" + nylon.work_dir);
